from unittest.mock import patch

import pytest

from workspaces.capability.schema import CapabilityExecution
from workspaces.capability.services.capability_info import CapabilityInfo
from workspaces.capability.services.capability_service import CapabilityService

pytest_plugins = ["testing.utils.conftest"]


@pytest.mark.usefixtures("mock_capability_service")
class TestCapabilityService:
    def test_on_ingestion_complete(
        self,
        mock_capability_service: CapabilityService,
        mock_capability_info: CapabilityInfo,
        mock_capability_execution: CapabilityExecution,
    ):
        fake_subject = {
            "type": "WorkflowRequest",
            "workflow_request_id": -1,
            "execution_wf_id": "-1",
        }

        fake_ingestion_complete_msg = {
            "subject": fake_subject,
            "service": "workflow",
            "routing_key": "workflow",
            "type": "ingestion-complete",
        }
        save_entity_old_call_count = mock_capability_info.save_entity.call_count
        mock_capability_service.on_ingestion_complete(**fake_ingestion_complete_msg)
        assert mock_capability_info.save_entity.call_count == save_entity_old_call_count + 1
        (request,) = mock_capability_info.save_entity.call_args.args
        assert request.ingested is True
